@@ -4,8 +4,7 @@
 #                                                                                 
 #    This program is free software; you can redistribute it and/or modify         
 #    it under the terms of the GNU General Public License as published by         
-#    the Free Software Foundation; either version 2 of the License, or            
-#    (at your option) any later version.                                          
+#    the Free Software Foundation, version 2.                                      
 #                                                                                 
 #    This program is distributed in the hope that it will be useful,              
 #    but WITHOUT ANY WARRANTY; without even the implied warranty of               
@@ -63,4 +62,5 @@ class License(object):
         """ Set the DC.rightsHolder field. """
         self.annotations[RIGHTSHOLDER_KEY] = rhdata
 
-    license = property(fget=getRightsLicense, fset=setRightsLicense)
+    license = property(getRightsLicense, setRightsLicense)
+    holder = property(getRightsHolder, setRightsHolder)
