@@ -1,9 +1,27 @@
+##################################################################################
+#    Copyright (c) 2004-2009 Utah State University, All rights reserved.
+#    Portions copyright 2009 Massachusetts Institute of Technology, All rights reserved.
+#                                                                                 
+#    This program is free software; you can redistribute it and/or modify         
+#    it under the terms of the GNU General Public License as published by         
+#    the Free Software Foundation, version 2.                                      
+#                                                                                 
+#    This program is distributed in the hope that it will be useful,              
+#    but WITHOUT ANY WARRANTY; without even the implied warranty of               
+#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                
+#    GNU General Public License for more details.                                 
+#                                                                                 
+#    You should have received a copy of the GNU General Public License            
+#    along with this program; if not, write to the Free Software                  
+#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA    
+#                                                                                 
+##################################################################################
 from Products.CMFPlone.tests import PloneTestCase
 from unittest import TestSuite, makeSuite
 from Testing import ZopeTestCase
 from Testing.ZopeTestCase import user_name
 from AccessControl import Unauthorized
-from base import ContentLicensingTestCase
+from base import ContentLicensingTestCase, BlobContentLicensingTestCase
 from zope.component import getUtility
 from zope.event import notify
 from zope.lifecycleevent import ObjectModifiedEvent
@@ -64,9 +82,12 @@ class TestContentLicensing(ContentLicensingTestCase):
         self.assertEqual(self.clutil.getLicenseAndHolderFromObject(img1)[1][0],
                          'GNU Free Documentation License')
 
+class BlobTestContentLicensing(BlobContentLicensingTestCase, TestContentLicensing):
+    pass
 
 def test_suite():
     suite = TestSuite()
     suite.addTest(makeSuite(TestContentLicensing))
+    suite.addTest(makeSuite(BlobTestContentLicensing))
     return suite
 
